from rumus_mat import RumusMatematika

print("Hello from main-app!")
print(f"Luas persegi dengan sisi 4 adalah {RumusMatematika.luas_persegi(4)}")
print(f"4 + 2 = {RumusMatematika.tambah(4, 2)}")
print(f"4 - 2 = {RumusMatematika.kurang(4, 2)}")
print(f"4 * 2 = {RumusMatematika.kali(4, 2)}")
print(f"4 / 2 = {RumusMatematika.bagi(4, 2)}")

print("Hello World!")
